# frozen_string_literal: true

module GemCodebreaker
  class CodeMaker
    attr_reader :plus_match, :minus_match, :empty_match

    def initialize(game_code, user_code)
      @game_code = game_code
      @user_code = user_code
      @plus_match = 0
      @minus_match = 0
      @empty_match = 0
    end

    def calculate_result_code
      count_plus_marker
      count_minus_and_empty_answer
    end

    private

    def count_plus_marker
      data = @game_code.zip(@user_code)
      data.delete_if { |game_code_item, user_code_item| @plus_match += 1 if game_code_item == user_code_item }
      @game_code, @user_code = data.transpose
    end

    def count_minus_and_empty_answer
      return if @game_code.nil?

      @game_code.each do |secret_code_item|
        if @user_code.include?(secret_code_item)
          @minus_match += 1
          @user_code.delete_at(@user_code.index(secret_code_item))
        else
          @empty_match += 1
        end
      end
    end
  end
end
