# frozen_string_literal: true

module GemCodebreaker
  class GameConfig
    GAME_LEVEL = {
      easy: {
        attempts: 15,
        hints: 2
      },
      medium: {
        attempts: 10,
        hints: 1
      },
      hell: {
        attempts: 5,
        hints: 1
      },
      strong_hell: {
        attempts: 1,
        hints: 0
      }
    }.freeze

    include Validator

    attr_reader :user_nick_name, :difficulty, :max_attempts, :max_hints, :user_attempts, :user_hints

    def initialize(user, level)
      check_difficulty(level)
      @user_nick_name = user.nick_name
      @difficulty = level
      @max_attempts = GAME_LEVEL[level][:attempts]
      @max_hints = GAME_LEVEL[level][:hints]
      @user_attempts = 0
      @user_hints = 0
    end

    def increase_user_attempts
      @user_attempts += 1
    end

    def increase_user_hints
      @user_hints += 1
    end

    def attempts_used?
      @user_attempts >= @max_attempts
    end

    def hints_used?
      @user_hints >= @max_hints
    end

    def reset_user_attempts_hints
      @user_attempts = 0
      @user_hints = 0
    end

    private

    def check_difficulty(difficulty)
      validate_inclusion(GAME_LEVEL.keys, difficulty)
    end
  end
end
